[libpng16] Imported from libpng-1.6.17beta04.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index 4b57083..38dcf0a 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,4 +1,4 @@
-Libpng 1.6.17beta04 - February 18, 2015
+Libpng 1.6.17beta04 - February 21, 2015
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -51,9 +51,10 @@
     by the user at build time or run time.  This provides a more robust
     defense against DOS and as-yet undiscovered overflows.
 
-Version 1.6.17beta04 [February 18, 2015]
+Version 1.6.17beta04 [February 21, 2015]
   Added PNG_WRITE_CUSTOMIZE_COMPRESSION_SUPPORTED macro, on by default.
   Allow user to call png_get_IHDR() with NULL arguments (Reuben Hawkins).
+  Rebuilt configure scripts with automake-1.15 and libtool-2.4.6
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/CHANGES b/CHANGES
index 4fd01ab..a1486fc 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5152,9 +5152,10 @@
     by the user at build time or run time.  This provides a more robust
     defense against DOS and as-yet undiscovered overflows.
 
-Version 1.6.17beta04 [February 18, 2015]
+Version 1.6.17beta04 [February 21, 2015]
   Added PNG_WRITE_CUSTOMIZE_COMPRESSION_SUPPORTED macro, on by default.
   Allow user to call png_get_IHDR() with NULL arguments (Reuben Hawkins).
+  Rebuilt configure scripts with automake-1.15 and libtool-2.4.6
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/INSTALL b/INSTALL
index 61ea591..0e75307 100644
--- a/INSTALL
+++ b/INSTALL
@@ -17,7 +17,7 @@
  XII. Configuring for compiler xxx:
 XIII. Removing unwanted object code
  XIV. Changes to the build and configuration of libpng in libpng-1.5.x
-  XV. Configuring libpng for multiprocessing
+  XV. Setjmp/longjmp issues
  XVI. Other sources of information about libpng
 
 I. Simple installation
@@ -362,7 +362,7 @@
 libpng, because than the settings would not accurately reflect the settings
 that were used to build libpng.
 
-XV. Configuring libpng for multiprocessing
+XV. Setjmp/longjmp issues
 
 Libpng uses setjmp()/longjmp() for error handling.  Unfortunately setjmp()
 is known to be not thread-safe on some platforms and we don't know of
@@ -375,6 +375,11 @@
 
 in your pnglibconf.h or pngusr.h.
 
+Starting with libpng-1.6.0, the library included a "simplified API".
+This requires setjmp/longjmp, so you must either build the library
+with PNG_SETJMP_SUPPORTED defined, or with PNG_SIMPLIFIED_READ_SUPPORTED
+and PNG_SIMPLIFIED_WRITE_SUPPORTED undefined.
+
 XVI. Other sources of information about libpng:
 
 Further information can be found in the README and libpng-manual.txt
diff --git a/LICENSE b/LICENSE
index 77d1878..2bc8c3d 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.6.17beta04, February 17, 2015, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.17beta04, February 21, 2015, are
 Copyright (c) 2004, 2006-2015 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-February 17, 2015
+February 21, 2015
diff --git a/README b/README
index c660cd6..66b6598 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.17beta04 - February 17, 2015 (shared library 16.0)
+README for libpng version 1.6.17beta04 - February 21, 2015 (shared library 16.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index af8301c..084ee0f 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.6.17beta04 - February 18, 2015
+ libpng version 1.6.17beta04 - February 21, 2015
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.6.17beta04 - February 18, 2015
+ libpng versions 0.97, January 1998, through 1.6.17beta04 - February 21, 2015
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2015 Glenn Randers-Pehrson
 
@@ -650,7 +650,7 @@
 The PNG specification allows the width and height of an image to be as
 large as 2^31-1 (0x7fffffff), or about 2.147 billion rows and columns.
 Larger images will be rejected immediately with a png_error() call. If
-you wish to reduce these limits, you can use
+you wish to change these limits, you can use
 
    png_set_user_limits(png_ptr, width_max, height_max);
 
@@ -5275,7 +5275,7 @@
 
 XVI. Y2K Compliance in libpng
 
-February 18, 2015
+February 21, 2015
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index 4a2dc64..278d176 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "February 18, 2015"
+.TH LIBPNG 3 "February 21, 2015"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.6.17beta04
 .SH SYNOPSIS
@@ -504,7 +504,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.6.17beta04 - February 18, 2015
+ libpng version 1.6.17beta04 - February 21, 2015
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -515,7 +515,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.6.17beta04 - February 18, 2015
+ libpng versions 0.97, January 1998, through 1.6.17beta04 - February 21, 2015
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2015 Glenn Randers-Pehrson
 
@@ -1154,7 +1154,7 @@
 The PNG specification allows the width and height of an image to be as
 large as 2^(31\-1 (0x7fffffff), or about 2.147 billion rows and columns.
 Larger images will be rejected immediately with a png_error() call. If
-you wish to reduce these limits, you can use
+you wish to change these limits, you can use
 
    png_set_user_limits(png_ptr, width_max, height_max);
 
@@ -5779,7 +5779,7 @@
 
 .SH XVI. Y2K Compliance in libpng
 
-February 18, 2015
+February 21, 2015
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -6094,7 +6094,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.6.17beta04 - February 18, 2015:
+Libpng version 1.6.17beta04 - February 21, 2015:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -6117,7 +6117,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.6.17beta04, February 18, 2015, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.17beta04, February 21, 2015, are
 Copyright (c) 2004,2006-2014 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -6216,7 +6216,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-February 18, 2015
+February 21, 2015
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 10e9752..225f040 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "February 17, 2015"
+.TH LIBPNGPF 3 "February 21, 2015"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.6.17beta04
 (private functions)
diff --git a/png.5 b/png.5
index b7f4a08..50e4e2e 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "February 17, 2015"
+.TH PNG 5 "February 21, 2015"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index a006f4d..5af6080 100644
--- a/png.c
+++ b/png.c
@@ -772,13 +772,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.6.17beta04 - February 17, 2015" PNG_STRING_NEWLINE \
+     "libpng version 1.6.17beta04 - February 21, 2015" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2015 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.6.17beta04 - February 17, 2015\
+      return "libpng version 1.6.17beta04 - February 21, 2015\
       Copyright (c) 1998-2015 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index d7343b0..e17347e 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.6.17beta04 - February 17, 2015
+libpng version 1.6.17beta04 - February 21, 2015
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 355b221..8643ebe 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.6.17beta04 - February 17, 2015
+ * libpng version 1.6.17beta04 - February 21, 2015
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 0a4e702..ad46959 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.6.17beta04 - February 17, 2015
+Makefiles for  libpng version 1.6.17beta04 - February 21, 2015
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 7c45860..d58e381 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -2,7 +2,7 @@
 
 /* pnglibconf.h - library build configuration */
 
-/* Libpng version 1.6.17beta04 - February 17, 2015 */
+/* Libpng version 1.6.17beta04 - February 21, 2015 */
 
 /* Copyright (c) 1998-2014 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index 2cd068c..e35797e 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.6.17beta04, February 18, 2015
  * Copyright (c) 1998-2015 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.6.17beta04, February 18, 2015: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -244,7 +244,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.6.17beta04, February 18, 2015, are
  * Copyright (c) 2004, 2006-2015 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -356,7 +356,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    February 18, 2015
+ *    February 21, 2015
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -426,7 +426,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.6.17beta04"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.6.17beta04 - February 18, 2015\n"
+     " libpng version 1.6.17beta04 - February 21, 2015\n"
 
 #define PNG_LIBPNG_VER_SONUM   16
 #define PNG_LIBPNG_VER_DLLNUM  16
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.6.17beta04, February 18, 2015
+ * libpng version 1.6.17beta04, February 21, 2015
  * Copyright (c) 1998-2015 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.6.17beta04, February 18, 2015: Glenn
+ *   libpng versions 0.97, January 1998, through 1.6.17beta04, February 21, 2015: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -244,7 +244,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.6.17beta04, February 18, 2015, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.17beta04, February 21, 2015, are
  * Copyright (c) 2004, 2006-2015 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5